pub struct EntryState { /* private fields */ }Implementations
Sourceimpl EntryState
impl EntryState
Sourcepub fn new_detached() -> Self
pub fn new_detached() -> Self
Create an entry state with no workspace root and no main file.
Sourcepub fn new_workspace(root: ImmutPath) -> Self
pub fn new_workspace(root: ImmutPath) -> Self
Create an entry state with a workspace root and no main file.
Sourcepub fn new_rooted(root: ImmutPath, main: Option<FileId>) -> Self
pub fn new_rooted(root: ImmutPath, main: Option<FileId>) -> Self
Create an entry state with a workspace root and an optional main file.
Sourcepub fn new_rootless(entry: ImmutPath) -> Option<Self>
pub fn new_rootless(entry: ImmutPath) -> Option<Self>
Create an entry state with only a main file given.
pub fn main(&self) -> Option<FileId>
pub fn root(&self) -> Option<ImmutPath>
pub fn workspace_root(&self) -> Option<ImmutPath>
pub fn select_in_workspace(&self, id: FileId) -> EntryState
pub fn try_select_path_in_workspace( &self, p: &Path, allow_rootless: bool, ) -> ZResult<Option<EntryState>>
pub fn is_detached(&self) -> bool
pub fn is_inactive(&self) -> bool