pub struct SourceDb {
pub revision: NonZeroUsize,
pub shared: Arc<RwLock<SharedState<SourceCache>>>,
pub slots: Arc<Mutex<FxHashMap<TypstFileId, SourceCache>>>,
pub do_reparse: bool,
}Fields
revision: NonZeroUsizeslots: Arc<Mutex<FxHashMap<TypstFileId, SourceCache>>>The slots for all the files during a single lifecycle.
do_reparse: boolWhether to reparse the file when it is changed.
Default to true.
Implementations
Sourceimpl SourceDb
impl SourceDb
pub fn take_state(&mut self) -> SourceState
Sourcepub fn set_do_reparse(&mut self, do_reparse: bool)
pub fn set_do_reparse(&mut self, do_reparse: bool)
Set the do_reparse flag that indicates whether to reparsing the file
instead of creating a new Source when the file is changed.
Default to true.
You usually want to set this flag to true for better performance.
However, one could disable this flag for debugging purpose.
Sourcepub fn memory_usage(&self) -> usize
pub fn memory_usage(&self) -> usize
Returns the overall memory usage for the stored files.
Sourcepub fn iter_dependencies_dyn<'a>(
&'a self,
p: &'a impl FsProvider,
f: &mut dyn FnMut(ImmutPath),
)
pub fn iter_dependencies_dyn<'a>( &'a self, p: &'a impl FsProvider, f: &mut dyn FnMut(ImmutPath), )
Get all the files that are currently in the VFS.
This is typically corresponds to the file dependencies of a single compilation.
When you don’t reset the vfs for each compilation, this function will still return remaining files from the previous compilation.
Sourcepub fn file(
&self,
id: TypstFileId,
fid: FileId,
p: &impl FsProvider,
) -> FileResult<Bytes>
pub fn file( &self, id: TypstFileId, fid: FileId, p: &impl FsProvider, ) -> FileResult<Bytes>
Get file content by path.
Sourcepub fn source(
&self,
id: TypstFileId,
fid: FileId,
p: &impl FsProvider,
) -> FileResult<Source>
pub fn source( &self, id: TypstFileId, fid: FileId, p: &impl FsProvider, ) -> FileResult<Source>
Get source content by path and assign the source with a given typst global file id.
See Vfs::resolve_with_f for more information.